pub enum CreatePostcardError {
Reqwest(Error),
Serialize(Error),
Api(ApiError),
Json(Error, String),
}Expand description
Errors that can occur while performing a Lob “create postcard” request.
Variants
Reqwest(Error)
HTTP or network error from reqwest.
Serialize(Error)
Failed to serialize the json request
Api(ApiError)
An Api Error From Lob
Json(Error, String)
Failed to parse the JSON response.
Contains the parse error and the raw response body.