pub enum MailType {
UspsFirstClass,
UspsStandard,
}Expand description
An enum designating the mail postage type
Variants
UspsFirstClass
usps_first_class - (default)
UspsStandard
usps_standard - a cheaper option which is less predictable and takes longer to deliver. usps_standard cannot be used with 4x6 postcards or for any postcards sent outside of the United States.