UseType

Enum UseType 

pub enum UseType {
    Marketing,
    Operational,
}
Identifying your mail use type helps Lob populate the right mail settings and postage options to ensure your mail is produced and delivered in an optimal way. Lob requires that you identify—or tag—your mail with one of the following use type options:

Variants



Marketing

Marketing mail: Any mailers that are sent for marketing, advertising, and promotional purposes



Operational

Operational mail: All other mail, typically transactional or functional in nature, such as invoices, adverse action notices, statements, and other confidential mail that include sensitive PII/PHI data